@@ -11,19 +11,19 @@ from zort.fit import return_mag_model
 
 
 def _plot_axis(ax, object, hmjd_min, hmjd_max, insert_radius,
-               model_params=None):
+               object_model_params=None):
     if object.color == 'i':
         color = 'k'
     else:
         color = object.color
 
-    if model_params:
-        t0 = model_params['t_0']
-        t_eff = model_params['t_E']
-        a_type = model_params['a_type']
-        f0 = model_params['f_0']
-        f1 = model_params['f_1']
-        t_fit = np.linspace(hmjd_min, hmjd_max, 1000)
+    if object_model_params:
+        t0 = object_model_params['t_0']
+        t_eff = object_model_params['t_E']
+        a_type = object_model_params['a_type']
+        f0 = object_model_params['f_0']
+        f1 = object_model_params['f_1']
+        t_fit = np.linspace(hmjd_min-insert_radius, hmjd_max+insert_radius, 1000)
         mag_model = return_mag_model(t_fit, t0, t_eff, a_type, f0, f1)
         for a in ax:
             a.plot(t_fit, mag_model, color='k', alpha=.3)
@@ -53,6 +53,7 @@ def _plot_axis(ax, object, hmjd_min, hmjd_max, insert_radius,
     ax[1].set_ylabel('Magnitude')
     ax[1].set_xlabel('Observation Date')
     ax[1].set_title('%i Days Around Peak' % insert_radius)
+    ax[1].set_facecolor((.8, .8, .8, .35))
 
 
 def plot_object(filename, object, insert_radius=30, model_params=None):
@@ -62,8 +63,13 @@ def plot_object(filename, object, insert_radius=30, model_params=None):
     fig, ax = plt.subplots(1, 2, figsize=(12, 4))
     fig.subplots_adjust(hspace=0.4)
 
+    if model_params is None or object.color not in model_params:
+        object_model_params = None
+    else:
+        object_model_params = model_params[object.color]
+
     _plot_axis(ax, object, hmjd_min, hmjd_max, insert_radius,
-               model_params=model_params)
+               object_model_params=object_model_params)
 
     fig.savefig(filename, dpi=300, bbox_inches='tight', pad_inches=0.05)
     print('---- Lightcurve saved: %s' % filename)
@@ -72,7 +78,7 @@ def plot_object(filename, object, insert_radius=30, model_params=None):
 
 def plot_objects(filename, object_g=None, object_r=None,
                  object_i=None, insert_radius=30,
-                 model_params=None, model_color=None):
+                 model_params=None):
     if object_g is None and object_r is None and object_i is None:
         raise Exception('At least one object must be set to generate lightcurves.')
 
@@ -80,7 +86,7 @@ def plot_objects(filename, object_g=None, object_r=None,
     objects = [obj for obj in objects if obj is not None]
 
     if len(objects) == 1:
-        plot_object(filename, objects[0])
+        plot_object(filename, objects[0], model_params=model_params)
         return
     elif len(objects) == 2:
         N_rows = 2
@@ -97,12 +103,12 @@ def plot_objects(filename, object_g=None, object_r=None,
     fig.subplots_adjust(hspace=0.4)
 
     for i, object in enumerate(objects):
-        if model_color and object.color == model_color:
-            object_model_params = model_params
-        else:
+        if model_params is None or object.color not in model_params:
             object_model_params = None
+        else:
+            object_model_params = model_params[object.color]
         _plot_axis(ax[i], object, hmjd_min, hmjd_max, insert_radius,
-                   model_params=object_model_params)
+                   object_model_params=object_model_params)
 
     fig.savefig(filename, dpi=300, bbox_inches='tight', pad_inches=0.05)
     print('---- Lightcurves saved: %s' % filename)
