@@ -10,11 +10,10 @@ import numpy as np
 from astropy.coordinates import SkyCoord
 import astropy.units as u
 
-from zort.lightcurve import Lightcurve
 from zort.object import Object
 from zort.plot import plot_objects
 from zort.utils import return_filename, return_objects_map_filename, \
-    return_radec_map_filename, filterid_dict
+    return_radec_map_filename
 
 
 ################################
@@ -35,18 +34,21 @@ class Source:
                  lightcurve_position_g=None,
                  lightcurve_position_r=None,
                  lightcurve_position_i=None,
-                 apply_catmask=False, PS_g_minus_r=0,
+                 apply_catmask=True, PS_g_minus_r=0,
                  objects_map=None,
-                 radec_map=None):
+                 radec_map=None,
+                 lightcurve_file_pointer=None,
+                 check_initialization=True):
         # Load filenames and check for existence
         self.filename = return_filename(filename)
-        self.objects_map_filename = return_objects_map_filename(filename)
-        self.radec_map_filename = return_radec_map_filename(filename)
+        self._objects_map_filename = None
+        self._radec_map_filename = None
 
-        self._check_initialization(object_id_g, object_id_r, object_id_i,
-                                   lightcurve_position_g,
-                                   lightcurve_position_r,
-                                   lightcurve_position_i)
+        if check_initialization:
+            self._check_initialization(object_id_g, object_id_r, object_id_i,
+                                       lightcurve_position_g,
+                                       lightcurve_position_r,
+                                       lightcurve_position_i)
 
         self.apply_catmask = apply_catmask
         self.PS_g_minus_r = PS_g_minus_r
@@ -59,6 +61,7 @@ class Source:
         else:
             self.radec_map = None
 
+        self.lightcurve_file_pointer = lightcurve_file_pointer
         objects = self._load_objects(object_id_g, object_id_r, object_id_i,
                                      lightcurve_position_g,
                                      lightcurve_position_r,
@@ -68,12 +71,37 @@ class Source:
         self.object_i = objects[2]
         self.objects = [o for o in objects if o is not None]
 
-        radec = self._calculate_radec()
-        self.ra = radec[0]
-        self.dec = radec[1]
-
+        self._radec = None
         self._glonlat = None
 
+    @property
+    def objects_map_filename(self):
+        if self._objects_map_filename is None:
+            self._objects_map_filename = return_objects_map_filename(self.filename)
+        return self._objects_map_filename
+
+    @property
+    def radec_map_filename(self):
+        if self._radec_map_filename is None:
+            self._radec_map_filename = return_radec_map_filename(self.filename)
+        return self._radec_map_filename
+
+    @property
+    def radec(self):
+        if self._radec is None:
+            ra = np.mean([obj.ra for obj in self.objects if obj is not None])
+            dec = np.mean([obj.dec for obj in self.objects if obj is not None])
+            self._radec = [ra, dec]
+        return self._radec
+
+    @property
+    def ra(self):
+        return self.radec[0]
+
+    @property
+    def dec(self):
+        return self.radec[1]
+
     @property
     def glonlat(self):
         if self._glonlat is None:
@@ -143,13 +171,16 @@ class Source:
         if lightcurve_position is not None:
             obj = Object(self.filename,
                          lightcurve_position=lightcurve_position,
-                         objects_map=self.objects_map)
+                         objects_map=self.objects_map,
+                         apply_catmask=self.apply_catmask,
+                         lightcurve_file_pointer=self.lightcurve_file_pointer)
         else:
             if self.objects_map is None:
                 self.objects_map = self.load_objects_map()
             obj = Object(self.filename,
                          object_id=object_id,
-                         objects_map=self.objects_map)
+                         objects_map=self.objects_map,
+                         lightcurve_file_pointer=self.lightcurve_file_pointer)
         if obj.color != color:
             str = "Color of 'object_id_{color}' is {color_obj}. " \
                   "Must be {color}.".format(color=color,
@@ -170,11 +201,6 @@ class Source:
                                      color='i')
         return object_g, object_r, object_i
 
-    def _calculate_radec(self):
-        ra = np.mean([obj.ra for obj in self.objects if obj is not None])
-        dec = np.mean([obj.dec for obj in self.objects if obj is not None])
-        return ra, dec
-
     def load_objects_map(self):
         objects_map_filename = self.objects_map_filename
         objects_map = pickle.load(open(objects_map_filename, 'rb'))
@@ -186,20 +212,19 @@ class Source:
         return radec_map
 
     def plot_lightcurves(self, filename=None, insert_radius=30,
-                         model_params=None, model_color=None):
+                         model_params=None):
         if filename is None:
             object_ids = '_'.join([str(obj.object_id) for obj in self.objects
                                    if obj is not None])
             filename = '%s_%s.png' % (self.filename.replace('.txt', ''),
                                       object_ids)
-
+        print('plot_lightcurves from source')
         plot_objects(filename=filename,
                      object_g=self.object_g,
                      object_r=self.object_r,
                      object_i=self.object_i,
                      insert_radius=insert_radius,
-                     model_params=model_params,
-                     model_color=model_color)
+                     model_params=model_params)
 
 
 def create_source_from_object(object, locate_siblings=True, radius_as=2, skip_filterids=None):
